package com.idea.customerManagement.service;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.idea.buildManage.mapper.ParkFloorDiscMapper;
import com.idea.buildManage.mapper.ParkInfoMapper;
import com.idea.buildManage.mapper.ParkRoomExtendMapper;
import com.idea.buildManage.mapper.ParkRoomMapper;
import com.idea.buildManage.model.ParkFloorDisc;
import com.idea.buildManage.model.ParkInfo;
import com.idea.buildManage.model.ParkRoom;
import com.idea.buildManage.response.ParkRoomResponse;
import com.idea.customerManagement.dto.ContractManageDto;
import com.idea.customerManagement.dto.IntentionalDepositDto;
import com.idea.customerManagement.dto.RoomSelectionInfoDto;
import com.idea.customerManagement.mapper.CustomerManagementMapper;
import com.idea.customerManagement.mapper.IntentionalDepositExtendMapper;
import com.idea.customerManagement.mapper.IntentionalDepositMapper;
import com.idea.customerManagement.mapper.RoomSelectionInfoMapper;
import com.idea.customerManagement.model.*;
import com.idea.invoice.model.ReceiptManage;
import com.idea.invoice.model.ReceiptManageExample;
import com.idea.invoice.service.ReceiptManageService;
import com.idea.invoice.util.InvoiceConstant;
import com.idea.invoice.util.InvoiceUtil;
import com.idea.paymentManagement.mapper.PayLogExtendMapper;
import com.idea.paymentManagement.mapper.PayLogMapper;
import com.idea.paymentManagement.mapper.RefundDetailMapper;
import com.idea.paymentManagement.mapper.RefundManageMapper;
import com.idea.paymentManagement.model.PayLog;
import com.idea.paymentManagement.model.PayLogExample;
import com.idea.paymentManagement.model.RefundDetail;
import com.idea.paymentManagement.model.RefundManage;
import com.idea.util.DateUtils;
import com.idea.util.MoneyUtils;
import com.idea.util.ReplaceWord;
import com.rockstar.common.base.BaseService;
import com.rockstar.common.domain.AjaxResult;
import com.rockstar.frame.model.FrameUser;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.frame.model.extend.Tablepar;
import com.rockstar.frame.service.FrameUserService;
import com.rockstar.shiro.util.ShiroUtils;
import com.rockstar.system.service.SysDictService;
import com.rockstar.util.MD5Util;
import com.rockstar.util.SnowflakeIdWorker;
import com.rockstar.util.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletResponse;
import java.util.*;

@Slf4j
@Service
public class IntentionalDepositService implements BaseService<IntentionalDeposit, IntentionalDepositExample> {

    @Autowired
    private IntentionalDepositMapper modelMapper;
    @Autowired
    private CustomerManagementMapper customerManagementMapper;
    @Autowired
    private ParkInfoMapper parkInfoMapper;
    @Autowired
    private ParkFloorDiscMapper parkFloorDiscMapper;
    @Autowired
    private FrameUserService frameUserService;
    @Autowired
    private IntentionalDepositExtendMapper extendMapper;
    @Autowired
    private ParkRoomExtendMapper roomExtendMapper;
    @Autowired
    private RoomSelectionInfoMapper roomSelectionInfoMapper;
    @Autowired
    private ParkRoomMapper parkRoomMapper;
    @Autowired
    private ContractManageService contractManageService;
    @Autowired
    private PayLogMapper payLogMapper;
    @Autowired
    private ReceiptManageService receiptManageService;
    @Autowired
    private BuyerService buyerService;
    @Autowired
    private SysDictService sysDictService;
    @Autowired
    private RefundManageMapper refundManageMapper;
    @Autowired
    private RefundDetailMapper refundDetailMapper;
    @Autowired
    private PayLogExtendMapper payLogExtendMapper;


    @Override
    public int deleteByPrimaryKey(String s) {
        return modelMapper.deleteByPrimaryKey(s);
    }

    @Override
    public int insertSelective(IntentionalDeposit intentionalDeposit) {
        intentionalDeposit.setId(IdUtil.simpleUUID());
        return modelMapper.insertSelective(intentionalDeposit);
    }

    public int insertWithoutId(IntentionalDeposit intentionalDeposit) {
        return modelMapper.insertSelective(intentionalDeposit);
    }

    @Override
    public IntentionalDeposit selectByPrimaryKey(String s) {
        return modelMapper.selectByPrimaryKey(s);
    }

    @Override
    public int updateByPrimaryKeySelective(IntentionalDeposit intentionalDeposit) {
        return modelMapper.updateByPrimaryKeySelective(intentionalDeposit);
    }

    @Override
    public int updateByExampleSelective(IntentionalDeposit intentionalDeposit, IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.updateByExampleSelective(intentionalDeposit, intentionalDepositExample);
    }

    @Override
    public int updateByExample(IntentionalDeposit intentionalDeposit, IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.updateByExample(intentionalDeposit, intentionalDepositExample);
    }

    @Override
    public List<IntentionalDeposit> selectByExample(IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.selectByExample(intentionalDepositExample);
    }

    @Override
    public long countByExample(IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.countByExample(intentionalDepositExample);
    }

    @Override
    public int deleteByExample(IntentionalDepositExample intentionalDepositExample) {
        return modelMapper.deleteByExample(intentionalDepositExample);
    }

    /**
     * 获取收据流水号（意向金编号）
     *
     * @param customerManagementId
     * @return
     */
    public String getSerialNumber(String customerManagementId) {
        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(customerManagementId);
        String groupId = customerManagement.getGroupId();
        String discId = customerManagement.getDiscId();
        // 查找这个小区已收取意向金的 数据量
        IntentionalDepositExample example = new IntentionalDepositExample();
        example.createCriteria().andGroupIdEqualTo(groupId);
        Long count = countByExample(example);
        String number = "";
        if (count.doubleValue() == 0) {
            number = "00001";
        } else {
            count++;
            number = String.format("%05d", count);
        }
        ParkInfo parkInfo = parkInfoMapper.selectByPrimaryKey(groupId);
        ParkFloorDisc parkFloorDisc = parkFloorDiscMapper.selectByPrimaryKey(discId);
        String serialNumber = parkInfo.getGroupName() + parkFloorDisc.getName() + "-YXJ" + number;
        return serialNumber;
    }

    /**
     * 获取收据流水号（定金编号）
     *
     * @param id
     * @return
     */
    public String getDepositSerialNumber(String id) {

        IntentionalDeposit deposit = selectByPrimaryKey(id);
        String groupId = deposit.getGroupId();
        String discId = deposit.getDiscId();
        ParkInfo parkInfo = parkInfoMapper.selectByPrimaryKey(groupId);
        ParkFloorDisc parkFloorDisc = parkFloorDiscMapper.selectByPrimaryKey(discId);
        // 查找这个小区已收取认购金的 数据量
        RoomSelectionInfoExample example = new RoomSelectionInfoExample();
        example.createCriteria().andGroupIdEqualTo(groupId).andStatusEqualTo(2);
        Long count = roomSelectionInfoMapper.countByExample(example);
        String number = "";
        if (count.doubleValue() == 0) {
            number = "00001";
        } else {
            count++;
            number = String.format("%05d", count);
        }
        String serialNumber = parkInfo.getGroupName() + parkFloorDisc.getName() + "-DJ" + number;
        return serialNumber;
    }


    /**
     * 意向金登记
     *
     * @param model
     * @return
     */
    @Transactional
    public int add(IntentionalDeposit model, String userId) {

        if(StringUtils.isEmpty(userId)){
            userId = ShiroUtils.getUserId();
        }
        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(model.getCustomerManagementId());
        String id = IdUtil.simpleUUID();
        // 已收取
        model.setStatus(1);
        model.setGroupId(customerManagement.getGroupId());
        model.setDiscId(customerManagement.getDiscId());
        model.setCreatedAt(new Date());
        model.setCreatedId(userId);
        model.setId(id);
        int result = insertWithoutId(model);

        // 票据管理 新增一条记录
        ReceiptManage receiptManage = new ReceiptManage();
        receiptManage.setBatchNumber(customerManagement.getBatchNumber());
        receiptManage.setRoomSelectionNumber(customerManagement.getRoomSelectionNumber());
        receiptManage.setBuyerName(customerManagement.getBuyerName());
        receiptManage.setCustomerManagementId(model.getCustomerManagementId());
        receiptManage.setBusinessId(id);
        // 票据类型 意向金
        receiptManage.setReceiptType("1");
        receiptManage.setReceiptMoney(model.getReceivedAmount());
        receiptManage.setReceiptNumber(model.getSerialNumber());
        receiptManage.setCreatedId(userId);
        receiptManageService.add(receiptManage,userId);

        // 收款记录 新增一条记录
        PayLog payLog = new PayLog();
        payLog.setId(IdUtil.simpleUUID());
        payLog.setHouseId(null);
        payLog.setContractId(null);
        payLog.setCustomerManagementId(model.getCustomerManagementId());
        // 收款类型 预收款
        payLog.setPayType(1);
        // 款项内容 意向金
        payLog.setContentType(7);
        payLog.setPayMoney(model.getReceivedAmount());
        payLog.setPayTime(new Date());
        payLog.setPaymentMethod(model.getPaymentMethod());
        payLog.setStatus(0);
        payLog.setCreatedAt(new Date());
        payLog.setCreatedBy(userId);
        payLog.setSerialNumber(model.getSerialNumber());
        payLog.setIsHide(1);
        payLog.setBankName(model.getBankName());
        payLog.setBankBranchName(model.getBankBranchName());
        payLog.setBankNumber(model.getBankNumber());
        payLogMapper.insertSelective(payLog);

        return result;
    }

    /**
     * 意向金修改
     *
     * @param model
     * @return
     */
    @Transactional
    public int edit(IntentionalDeposit model, String userId) {

        if(StringUtils.isEmpty(userId)){
            userId = ShiroUtils.getUserId();
        }
        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(model.getCustomerManagementId());
        model.setGroupId(customerManagement.getGroupId());
        model.setDiscId(customerManagement.getDiscId());
        model.setUpdatedAt(new Date());
        model.setUpdatedId(userId);
        int result = updateByPrimaryKeySelective(model);

        // 票据管理 修改一条记录
        ReceiptManageExample receiptManageExample = new ReceiptManageExample();
        receiptManageExample.createCriteria().andBusinessIdEqualTo(model.getId());
        List<ReceiptManage> receiptManages = receiptManageService.selectByExample(receiptManageExample);
        if(CollectionUtils.isNotEmpty(receiptManages)){
            ReceiptManage receiptManage = receiptManages.get(0);
            receiptManage.setReceiptMoney(model.getReceivedAmount());
            receiptManage.setUpdatedAt(new Date());
            receiptManage.setUpdatedId(userId);
            receiptManageService.updateByPrimaryKeySelective(receiptManage);
        }

        // 收款记录 修改一条记录
        PayLogExample payLogExample = new PayLogExample();
        payLogExample.createCriteria().andCustomerManagementIdEqualTo(model.getCustomerManagementId());
        List<PayLog> payLogs = payLogMapper.selectByExample(payLogExample);
        if(CollectionUtils.isNotEmpty(payLogs)){
            PayLog payLog = payLogs.get(0);
            payLog.setPayMoney(model.getReceivedAmount());
            payLog.setUpdatedAt(new Date());
            payLog.setUpdatedBy(userId);
            payLogMapper.updateByPrimaryKeySelective(payLog);
        }

        return result;
    }

    /**
     * 根据客户id查找意向金
     *
     * @param customerManagementId
     * @return
     */
    public IntentionalDepositDto getByCustomerManagementId(String customerManagementId) {

        IntentionalDepositExample example = new IntentionalDepositExample();
        example.createCriteria().andCustomerManagementIdEqualTo(customerManagementId);
        List<IntentionalDeposit> intentionalDeposits = modelMapper.selectByExampleWithBLOBs(example);
        if (CollectionUtils.isNotEmpty(intentionalDeposits)) {
            IntentionalDepositDto result = new IntentionalDepositDto();
            IntentionalDeposit intentionalDeposit = intentionalDeposits.get(0);
            BeanUtil.copyProperties(intentionalDeposit, result);
            FrameUser frameUser = frameUserService.selectByPrimaryKey(intentionalDeposit.getCreatedId());
            if (ObjectUtil.isNotNull(frameUser)) {
                result.setCreatedName(frameUser.getTruename());
            }
            return result;
        }
        return null;

    }

    /**
     * 分页
     *
     * @param tablepar
     * @param model
     * @param dt
     * @return
     */
    public PageInfo<IntentionalDepositDto> listByModel(Tablepar tablepar, IntentionalDepositDto model, DateTrans dt) {
        PageHelper.startPage(tablepar.getPageNum(), tablepar.getPageSize());
        List<IntentionalDepositDto> list = extendMapper.listByModel(model);
        PageInfo<IntentionalDepositDto> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 意向金转定金
     *
     * @param model
     * @return
     */
    @Transactional
    public int toDeposit(IntentionalDeposit model,String uerId) {

        if (StringUtils.isEmpty(uerId)){
            uerId = ShiroUtils.getUserId();
        }
        // 转定金
        model.setStatus(2);
        model.setHandleId(ShiroUtils.getUserId());
        model.setHandleDate(new Date());
        int result = modelMapper.updateByPrimaryKeySelective(model);

        String houseId = model.getHouseId();
        String customerManagementId = model.getCustomerManagementId();

        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(customerManagementId);
        // 购房状态 已选房
        customerManagement.setStatus(2);
        customerManagement.setHouseId(houseId);
        StringBuilder builder = new StringBuilder();

        // 拼接房屋名称
        ParkRoomResponse response = roomExtendMapper.getFullName(houseId);
        builder.append(response.getBuildName()).append("-").append(response.getRoomNo()).append(",");
        if (builder.length() > 0) {
            builder.deleteCharAt(builder.length() - 1);
        }
        customerManagement.setHouseName(builder.toString());
        customerManagementMapper.updateByPrimaryKeySelective(customerManagement);

        // 新增选房信息
        String roomSelectionInfoId = IdUtil.simpleUUID();
        RoomSelectionInfo roomSelectionInfo = new RoomSelectionInfo();
        roomSelectionInfo.setId(roomSelectionInfoId);
        roomSelectionInfo.setCustomerManagementId(customerManagementId);
        roomSelectionInfo.setHouseId(response.getId());
        roomSelectionInfo.setBuildId(response.getBuildId());
        roomSelectionInfo.setDiscId(response.getDiscId());
        roomSelectionInfo.setGroupId(response.getGroupId());
        roomSelectionInfo.setCreatedAt(new Date());
        roomSelectionInfo.setCreatedId(ShiroUtils.getUserId());
        roomSelectionInfo.setReceivableMoney(model.getReceivableMoney());
        roomSelectionInfo.setReceivedAmount(model.getReceivedAmount());
        // 收取状态 意向金转入
        roomSelectionInfo.setStatus(3);
        roomSelectionInfo.setSerialNumber(model.getDepositSerialNumber());
        roomSelectionInfo.setPaymentMethod(model.getPaymentMethod());
        roomSelectionInfo.setCollectionTime(model.getCollectionTime());
        roomSelectionInfoMapper.insertSelective(roomSelectionInfo);

        // 转定金后生成合同
        String contractId = IdUtil.simpleUUID();
        contractManageService.addContract(roomSelectionInfo, contractId,null);

        // 新增一条定金收款记录
        String payLogId = IdUtil.simpleUUID();
        PayLog payLog = new PayLog();
        payLog.setId(payLogId);
        payLog.setBusinessId(roomSelectionInfoId);
        payLog.setHouseId(houseId);
        payLog.setContractId(contractId);
        payLog.setCustomerManagementId(customerManagementId);
        // 收款类型 预收款
        payLog.setPayType(1);
        // 款项内容 定金
        payLog.setContentType(1);
        payLog.setPayMoney(model.getReceivedAmount());
        payLog.setPayTime(new Date());
        payLog.setPaymentMethod(model.getPaymentMethod());
        payLog.setStatus(0);
        payLog.setCreatedAt(new Date());
        payLog.setCreatedBy(ShiroUtils.getUserId());
        payLog.setSerialNumber(model.getDepositSerialNumber());
        payLog.setBankName(model.getBankName());
        payLog.setBankBranchName(model.getBankBranchName());
        payLog.setBankNumber(model.getBankNumber());
        payLogMapper.insertSelective(payLog);

        // 修改意向金对应的收款记录
        PayLog modelPayLog = payLogExtendMapper.getByBusinessId(model.getId());
        modelPayLog.setContractId(contractId);
        modelPayLog.setHouseId(houseId);
        modelPayLog.setIsConvert(1);
        modelPayLog.setConvertPayLogId(payLogId);
        modelPayLog.setConvertBusinessId(roomSelectionInfoId);
        payLogMapper.updateByPrimaryKeySelective(modelPayLog);


        // 更新房间状态
        ParkRoom parkRoom = new ParkRoom();
        parkRoom.setId(response.getId());
        parkRoom.setIsChoose(1);
        // 已认购
        parkRoom.setSoldStatus(2);
        parkRoomMapper.updateByPrimaryKeySelective(parkRoom);

        // 票据管理 新增一条记录
        ReceiptManage receiptManage = new ReceiptManage();
        receiptManage.setBatchNumber(customerManagement.getBatchNumber());
        receiptManage.setRoomSelectionNumber(customerManagement.getRoomSelectionNumber());
        receiptManage.setBuyerName(customerManagement.getBuyerName());
        receiptManage.setCustomerManagementId(model.getCustomerManagementId());
        receiptManage.setBusinessId(roomSelectionInfoId);
        // 票据类型 定金
        receiptManage.setReceiptType("2");
        receiptManage.setReceiptMoney(model.getReceivedAmount());
        receiptManage.setReceiptNumber(model.getDepositSerialNumber());
        // 已开
        receiptManage.setReceiptStatus(1);
        receiptManageService.add(receiptManage,uerId);
        // 更新关联的意向金数据 更新意向金票据关联票号
        ReceiptManageExample receiptManageExample = new ReceiptManageExample();
        receiptManageExample.createCriteria().andBusinessIdEqualTo(model.getId());
        List<ReceiptManage> receiptManages = receiptManageService.selectByExample(receiptManageExample);
        if (CollectionUtils.isNotEmpty(receiptManages)) {
            ReceiptManage manage = receiptManages.get(0);
            manage.setAssociationNumber(model.getDepositSerialNumber());
            // 已换票
            manage.setReceiptStatus(2);
            receiptManageService.updateByPrimaryKeySelective(manage);
        }


        return result;

    }

    /**
     * 退意向金
     *
     * @param model
     * @return
     */
    public int refund(IntentionalDeposit model) {

        // 退意向金
        model.setStatus(3);
        model.setHandleId(ShiroUtils.getUserId());
        model.setHandleDate(new Date());
        int result = modelMapper.updateByPrimaryKeySelective(model);

        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(model.getCustomerManagementId());

        // 新增一条退款记录
        String refundId = IdUtil.simpleUUID();
        RefundManage refundManage = new RefundManage();
        refundManage.setId(refundId);
        refundManage.setHouseId(model.getHouseId());
        refundManage.setContractId(null);
        refundManage.setCustomerManagementId(model.getCustomerManagementId());
        refundManage.setApplicant(ShiroUtils.getLoginName());
//        refundManage.setIdentityCard();
        refundManage.setBuyerName(customerManagement.getBuyerName());
        refundManage.setRefundAmount(model.getReceivedAmount());
        refundManage.setActualRefundAmount(model.getRefundMoney());
        refundManage.setCreatedId(ShiroUtils.getUserId());
        refundManage.setCreatedAt(new Date());
        refundManage.setIsHide(1);
        refundManageMapper.insertSelective(refundManage);

        RefundDetail detail = new RefundDetail();
        detail.setId(IdUtil.simpleUUID());
        // 意向金
        detail.setContentType(7);
        detail.setRefundManageId(refundId);
        detail.setType("意向金");
        detail.setReceivedAmount(model.getReceivedAmount());
        detail.setActualRefundAmount(model.getRefundMoney());
        detail.setCreatedId(ShiroUtils.getUserId());
        detail.setCreatedAt(new Date());
        detail.setIsHide(1);
        refundDetailMapper.insertSelective(detail);
        return result;
    }

    public IntentionalDepositDto getById(String id) {
        IntentionalDeposit intentionalDeposit = modelMapper.selectByPrimaryKey(id);
        IntentionalDepositDto intentionalDepositDto = new IntentionalDepositDto();
        String handleName = "";
        if (StringUtils.isNotEmpty(intentionalDeposit.getHandleId())) {
            FrameUser frameUser = frameUserService.selectByPrimaryKey(intentionalDeposit.getHandleId());
            handleName = frameUser == null ? "" : frameUser.getTruename();
        }
        BeanUtil.copyProperties(intentionalDeposit, intentionalDepositDto);
        intentionalDepositDto.setHandleName(handleName);
        return intentionalDepositDto;
    }

    /**
     * 意向金收据
     *
     * @param model
     * @param response
     */
    public void downLoadReceipt(IntentionalDeposit model, HttpServletResponse response) {

        IntentionalDeposit newRecord = selectByPrimaryKey(model.getId());
        String filePath = "/home/project/settleDown/tem/receipt.docx";
        String sealPath = "/home/project/settleDown/tem/seal.png";
        String fileName = "意向金收据.docx";
        String customerManagementId = newRecord.getCustomerManagementId();
        BuyerExample buyerExample = new BuyerExample();
        buyerExample.setOrderByClause("order_num asc");
        buyerExample.createCriteria().andCustomerManagementIdEqualTo(customerManagementId);
        List<Buyer> buyers = buyerService.selectByExample(buyerExample);
        StringBuilder builder = new StringBuilder();
        if (CollectionUtils.isNotEmpty(buyers)) {
            for (Buyer buyer : buyers) {
                builder.append(buyer.getName()).append(",");
            }
            if (builder.length() > 0) {
                builder.deleteCharAt(builder.length() - 1);
            }
        }
        String fullName = "（未选房）";
        // 意向金只有选房后 才有houseId
        if (StringUtils.isNotEmpty(newRecord.getHouseId())) {
            ParkRoomResponse roomResponse = roomExtendMapper.getFullName(newRecord.getHouseId());
            fullName = roomResponse.getGroupName() + "-"
                    + roomResponse.getDiscName() + "-"
                    + roomResponse.getBuildName() + "-"
                    + roomResponse.getRoomNo();
        }
        String serialNumber = newRecord.getSerialNumber();
        String collectionTime = DateUtils.parseDateToStr(DateUtils.DATE_CH, newRecord.getCollectionTime());
        String content = "意向金";
        String paymentMethod = "";
        String dictLabel = sysDictService.getDictLabel("COLLECTION_METHODS", newRecord.getPaymentMethod().toString());
        if (StringUtils.isNotEmpty(dictLabel)) {
            paymentMethod = dictLabel;
        }
        String receivedAmount = newRecord.getReceivedAmount().toString();
        String capital = MoneyUtils.amountConversion(receivedAmount);

        Map<String, Object> data = new HashMap<>();
        Map<String, Object> picData = new HashMap<>();
        Map<String, Object> sealData = new HashMap<>();
        Map<String, Object> settingData = new HashMap<>();
        Map<String, Object> settingInfoData;

        data.put("${serialNumber}", serialNumber);
        data.put("${name}", builder.toString());
        data.put("${collectionTime}", collectionTime);
        data.put("${content}", content);
        data.put("${paymentMethod}", paymentMethod);
        data.put("${fullName}", fullName);
        data.put("${capital}", capital);
        data.put("${receivedAmount}", receivedAmount);
        sealData.put("${seal}", sealPath);
        settingInfoData = new HashMap<>();
        settingInfoData.put("leftOffset", "50");
        settingInfoData.put("topOffset", "0");
        settingData.put("${seal}", settingInfoData);

        ReplaceWord.operateWord(response, filePath, fileName, data, picData, sealData, settingData);


    }

    /**
     * 收诚意金 凭证推送
     *
     * @param model
     * @return
     */
    public AjaxResult sendVoucher(IntentionalDepositDto model) {

        // 银行流水id
        String pkInformerId = model.getPkInformerId();
        IntentionalDeposit intentionalDeposit = selectByPrimaryKey(model.getId());
        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(intentionalDeposit.getCustomerManagementId());
        BuyerExample buyerExample = new BuyerExample();
        buyerExample.setOrderByClause("order_num");
        buyerExample.createCriteria().andCustomerManagementIdEqualTo(customerManagement.getId());
        List<Buyer> buyers = buyerService.selectByExample(buyerExample);
        Buyer buyer = buyers.get(0);

        JSONObject json = new JSONObject();
        JSONObject ar_gatherbill = new JSONObject();
        String srcsystemid = model.getId();
        String billdate = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, new Date());
        ar_gatherbill.put("srcsystemid", srcsystemid); //外系统标识,必选
        ar_gatherbill.put("pk_tradetype", InvoiceConstant.INVOICE_BUSINESS_F2_Cxx_06); //交易类型,必选
        ar_gatherbill.put("pk_org", InvoiceUtil.pk_org); //组织编码,必选
        ar_gatherbill.put("billdate", billdate); //单据日期
        ar_gatherbill.put("def2", srcsystemid); //外系统单据号，必填，
        json.put("ar_gatherbill", ar_gatherbill);

        JSONArray ar_gatheritem = new JSONArray();
        JSONObject ar_gatheritemJson = new JSONObject();
        ar_gatheritemJson.put("srcsystemid", srcsystemid); //外系统子表标识
        ar_gatheritemJson.put("objtype", "0"); //0=客户，1=供应商--判断customer和supplier是否必填，必选
        ar_gatheritemJson.put("customer", buyer.getIdentityCard()); //客商的纳税人识别号
        ar_gatheritemJson.put("money_cr", intentionalDeposit.getReceivedAmount()); //金额，必选
        ar_gatheritemJson.put("taxrate", "10"); //税率,必选，数字——3/10/6````
        ar_gatheritemJson.put("pk_balatype", "0"); //结算方式,必选，看云文档结算方式
        ar_gatheritemJson.put("pk_recpaytype", "001"); //付款业务类型传默认值“001”
        ar_gatheritemJson.put("prepay", "0"); //收款性质应收款时传"0",收款性质预收款时传"1"
        ar_gatheritemJson.put("recaccount", InvoiceUtil.bank_number); //收款银行账号,必填
//        ar_gatheritemJson.put("invoiceno","fphm"); //发票号码，非必选
        ar_gatheritemJson.put("scomment", buyer.getName()); //客户名称，必选
        ar_gatheritemJson.put("pk_subjcode", InvoiceConstant.INVOICE_PAYMENT_TYPE_AJ026); //收款类型
        ar_gatheritemJson.put("checktype", InvoiceConstant.INVOICE_RECEIPT_TYPE_3); //票据类型，必选，看云文档票据类型
        ar_gatheritemJson.put("checkno", intentionalDeposit.getSerialNumber()); //票据号，必选
        ar_gatheritemJson.put("def9", InvoiceConstant.INVOICE_BUSINESS_FORMAT_001); //业态，必选，看云文档业态
//        ar_gatheritemJson.put("def11", ""); //转出前房号编码，收除了诚意金之外的首期等需要选
        // TODO: 2024/11/14 具体编码应该是根据小区来的
        ar_gatheritemJson.put("def10", InvoiceConstant.INVOICE_MATERIAL_djjy); //项目档案编码，看云文档项目档案对照
        ar_gatheritemJson.put("top_billid", pkInformerId); //到账通知生单时,（银行流水中返回的id，见5.2.10到账通知认领查询pk_informer字段）
        ar_gatheritem.add(ar_gatheritemJson);
        json.put("ar_gatheritem", ar_gatheritem);

        try {
            String result = InvoiceUtil.gatheringbillAdd(json);
            JSONObject jsonObject = JSONObject.parseObject(result);
            if (jsonObject.getString("success").equals("true")) {
                intentionalDeposit.setNcJson(result);
                updateByPrimaryKeySelective(intentionalDeposit);
            }

        } catch (Exception e) {
            log.error("收诚意金凭证推送报错", e);
            return AjaxResult.error(e.getMessage());
        }
        return AjaxResult.success();
    }

    /**
     * 诚意金转定金 凭证推送
     *
     * @param id
     * @return
     */
    public AjaxResult sendToDepositVoucher(String id) {

        IntentionalDeposit intentionalDeposit = selectByPrimaryKey(id);
        CustomerManagement customerManagement = customerManagementMapper.selectByPrimaryKey(intentionalDeposit.getCustomerManagementId());
        BuyerExample buyerExample = new BuyerExample();
        buyerExample.setOrderByClause("order_num");
        buyerExample.createCriteria().andCustomerManagementIdEqualTo(customerManagement.getId());
        List<Buyer> buyers = buyerService.selectByExample(buyerExample);
        Buyer buyer = buyers.get(0);

        JSONObject json = new JSONObject();
        JSONObject ar_gatherbill = new JSONObject();
        String srcsystemid = MD5Util.encode(id);
        String billdate = DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, new Date());
        ar_gatherbill.put("srcsystemid", srcsystemid); //外系统标识,必选
        ar_gatherbill.put("pk_tradetype", InvoiceConstant.INVOICE_BUSINESS_F2_Cxx_07); //交易类型,必选
        ar_gatherbill.put("pk_org", InvoiceUtil.pk_org); //组织编码,必选
        ar_gatherbill.put("billdate", billdate); //单据日期
        ar_gatherbill.put("def2", srcsystemid); //外系统单据号，必填，
        json.put("ar_gatherbill", ar_gatherbill);

        JSONArray ar_gatheritem = new JSONArray();
        JSONObject ar_gatheritemJson = new JSONObject();
        ar_gatheritemJson.put("srcsystemid", srcsystemid); //外系统子表标识
        ar_gatheritemJson.put("objtype", "0"); //0=客户，1=供应商--判断customer和supplier是否必填，必选
        ar_gatheritemJson.put("customer", buyer.getIdentityCard()); //客商的纳税人识别号
        ar_gatheritemJson.put("money_cr", intentionalDeposit.getReceivedAmount()); //金额，必选
        ar_gatheritemJson.put("taxrate", "10"); //税率,必选，数字——3/10/6````
        ar_gatheritemJson.put("pk_balatype", "0"); //结算方式,必选，看云文档结算方式
        ar_gatheritemJson.put("pk_recpaytype", "001"); //付款业务类型传默认值“001”
        ar_gatheritemJson.put("prepay", "0"); //收款性质应收款时传"0",收款性质预收款时传"1"
        ar_gatheritemJson.put("recaccount", InvoiceUtil.bank_number); //收款银行账号,必填
//        ar_gatheritemJson.put("invoiceno","fphm"); //发票号码，非必选
        ar_gatheritemJson.put("scomment", buyer.getName()); //客户名称，必选
        ar_gatheritemJson.put("pk_subjcode", InvoiceConstant.INVOICE_PAYMENT_TYPE_AJ001); //收支项目编码，必选，看云文档收支项目对照
        ar_gatheritemJson.put("def11", customerManagement.getHouseId()); //转出前房号编码，必选
        ar_gatheritemJson.put("def9", InvoiceConstant.INVOICE_BUSINESS_FORMAT_001); //业态，必选，看云文档业态
//        ar_gatheritemJson.put("def12", ""); //转出后房号编码，换房业务时要选
        ar_gatheritemJson.put("def14", InvoiceConstant.INVOICE_PAYMENT_TYPE_AJ026); //原收支项目编码，定金转违约金项目时 必选
//        ar_gatheritemJson.put("def13", ""); //换票后票据号，换房业务必选
        ar_gatheritemJson.put("checktype", InvoiceConstant.INVOICE_RECEIPT_TYPE_3); //票据类型，必选，看云文档票据类型
        ar_gatheritemJson.put("checkno", intentionalDeposit.getDepositSerialNumber()); //票据号，必选
        // TODO: 2024/11/14 具体编码 未定
        ar_gatheritemJson.put("def10", InvoiceConstant.INVOICE_MATERIAL_djjy); //项目档案编码，看云文档项目档案对照
        ar_gatheritem.add(ar_gatheritemJson);
        json.put("ar_gatheritem", ar_gatheritem);

        try {
            String result = InvoiceUtil.gatheringbillTurn(json);
            JSONObject jsonObject = JSONObject.parseObject(result);
            if (jsonObject.getString("success").equals("true")) {
                intentionalDeposit.setNcJson(result);
                updateByPrimaryKeySelective(intentionalDeposit);
            }

        } catch (Exception e) {
            log.error("诚意金转定金凭证推送报错", e);
            return AjaxResult.error(e.getMessage());
        }
        return AjaxResult.success();

    }


}
