package com.idea.demo.service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.idea.demo.mapper.DemoApplyMapper;
import com.idea.demo.model.DemoApply;
import com.idea.demo.model.DemoApplyExample;
import com.rockstar.common.base.BaseService;
import com.rockstar.common.support.Convert;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.frame.model.extend.Tablepar;
import com.rockstar.util.SnowflakeIdWorker;
import com.rockstar.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class DemoApplyService implements BaseService<DemoApply, DemoApplyExample> {

    //文件mapper
    @Autowired
    private DemoApplyMapper modelMapper;

    /**
     * 分页查询
     *
     * @return
     */
    public PageInfo<DemoApply> list(Tablepar tablepar, DemoApply model, DateTrans dt) {
        PageHelper.startPage(tablepar.getPageNum(), tablepar.getPageSize());
        List<DemoApply> list = modelMapper.selectByExample(getCondition(model,dt));
        PageInfo<DemoApply> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 查询指定
     *
     * @return
     */
    public List<DemoApply> listAll(DemoApply model, DateTrans dt) {
        return modelMapper.selectByExample(getCondition(model,dt));
    }

    private DemoApplyExample getCondition(DemoApply model, DateTrans dt) {
        DemoApplyExample ex = new DemoApplyExample();
        ex.setOrderByClause("created_at asc");
        DemoApplyExample.Criteria criteria = ex.createCriteria();

        if(StringUtils.isNotEmpty(model.getComment())){
            criteria.andCommentLike("%"+model.getComment()+"%");
        }
        if(StringUtils.isNotEmpty(model.getTitle())){
            criteria.andTitleLike("%"+model.getTitle()+"%");
        }
        if(StringUtils.isNotEmpty(model.getStatus())){
            criteria.andStatusEqualTo(model.getStatus());
        }
        if(StringUtils.isNotEmpty(model.getType())){
            criteria.andTypeEqualTo(model.getType());
        }

        return ex;
    }

    @Override
    public int deleteByPrimaryKey(String ids) {
        List<String> lista = Convert.toListStrArray(ids);
        DemoApplyExample example = new DemoApplyExample();
        example.createCriteria().andIdIn(lista);
        return modelMapper.deleteByExample(example);
    }

    @Override
    public DemoApply selectByPrimaryKey(String id) {
        return modelMapper.selectByPrimaryKey(id);
    }

    @Override
    public int updateByPrimaryKeySelective(DemoApply record) {
        return modelMapper.updateByPrimaryKeySelective(record);
    }

    @Override
    public int updateByExampleSelective(DemoApply record, DemoApplyExample example) {
        return modelMapper.updateByExampleSelective(record, example);
    }

    @Override
    public int updateByExample(DemoApply record, DemoApplyExample example) {
        return modelMapper.updateByExample(record, example);
    }

    @Override
    public List<DemoApply> selectByExample(DemoApplyExample example) {
        return modelMapper.selectByExample(example);
    }

    @Override
    public long countByExample(DemoApplyExample example) {
        return modelMapper.countByExample(example);
    }

    public long countByExample(DemoApply model, DateTrans dt) {
        return modelMapper.countByExample(getCondition(model,dt));
    }

    @Override
    public int deleteByExample(DemoApplyExample example) {
        return modelMapper.deleteByExample(example);
    }

    public int insert(DemoApply record){
        record.setId(SnowflakeIdWorker.getUUID());
        return insertWithoutId(record);
    }

    public int insertWithoutId(DemoApply record){
        record.setCreatedAt(new Date());
        return modelMapper.insert(record);
    }

    @Override
    public int insertSelective(DemoApply record) {
        record.setId(SnowflakeIdWorker.getUUID());
        record.setCreatedAt(new Date());
        return modelMapper.insertSelective(record);
    }

}
