package com.idea.workPanel.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateUtil;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.idea.workPanel.enume.WorkTrendsTypeEnum;
import com.idea.workPanel.mapper.ParkWorkTrendsMapper;
import com.idea.workPanel.model.ParkWorkTrends;
import com.idea.workPanel.model.ParkWorkTrendsExample;
import com.rockstar.common.base.BaseService;
import com.rockstar.common.support.Convert;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.frame.model.extend.Tablepar;
import com.rockstar.util.SnowflakeIdWorker;
import com.rockstar.util.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class ParkWorkTrendsService implements BaseService<ParkWorkTrends, ParkWorkTrendsExample> {
    @Autowired
    private ParkWorkTrendsMapper modelMapper;


    @Override
    public int deleteByPrimaryKey(String ids) {
        List<String> lista = Convert.toListStrArray(ids);
        ParkWorkTrendsExample example = new ParkWorkTrendsExample();
        example.createCriteria().andIdIn(lista);
        return modelMapper.deleteByExample(example);
    }

    @Override
    public ParkWorkTrends selectByPrimaryKey(String id) {
        return modelMapper.selectByPrimaryKey(id);
    }
    @Override
    public int updateByPrimaryKeySelective(ParkWorkTrends record) {
        if(StringUtils.isEmpty(record.getId())){
            record.setId(SnowflakeIdWorker.getUUID());
            record.setCreatedAt(new Date());
            return modelMapper.insert(record);
        }
        return modelMapper.updateByPrimaryKeySelective(record);
    }

    @Override
    public int updateByExampleSelective(ParkWorkTrends record, ParkWorkTrendsExample example) {
        return modelMapper.updateByExampleSelective(record, example);
    }

    @Override
    public int updateByExample(ParkWorkTrends record, ParkWorkTrendsExample example) {
        return modelMapper.updateByExample(record, example);
    }

    @Override
    public List<ParkWorkTrends> selectByExample(ParkWorkTrendsExample example) {
        return modelMapper.selectByExample(example);
    }

    @Override
    public long countByExample(ParkWorkTrendsExample example) {
        return modelMapper.countByExample(example);
    }

    @Override
    public int deleteByExample(ParkWorkTrendsExample example) {
        return modelMapper.deleteByExample(example);
    }


    public int insertWithoutId(ParkWorkTrends record){
        return modelMapper.insert(record);
    }

    @Override
    public int insertSelective(ParkWorkTrends record) {
        record.setId(SnowflakeIdWorker.getUUID());
        return modelMapper.insertSelective(record);
    }

    public int insert(ParkWorkTrends record){
        record.setId(SnowflakeIdWorker.getUUID());
        return modelMapper.insert(record);
    }

    /**
     * 分页查询
     *
     * @return
     */
    public PageInfo<ParkWorkTrends> list(Tablepar tablepar, ParkWorkTrends model, DateTrans dt) {
        PageHelper.startPage(tablepar.getPageNum(), tablepar.getPageSize());
        List<ParkWorkTrends> list = modelMapper.selectByExample(getCondition(model,dt));
        PageInfo<ParkWorkTrends> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }
    /**
     * 查询指定
     *
     * @return
     */
    public List<ParkWorkTrends> listAll(ParkWorkTrends model, DateTrans dt) {
        return modelMapper.selectByExample(getCondition(model, dt));
    }

    private ParkWorkTrendsExample getCondition(ParkWorkTrends model, DateTrans dt) {
        ParkWorkTrendsExample ex = new ParkWorkTrendsExample();
        if(null == model){
            return ex;
        }
        ex.setOrderByClause("created_at desc");
        ParkWorkTrendsExample.Criteria criteria = ex.createCriteria();
        return ex;
    }

    // 获取当前极度的所有工作动态
    public List<ParkWorkTrends> getQuarterList() {
        List<Date> quarterTimes = getQuarterTime();
        ParkWorkTrendsExample ex = new ParkWorkTrendsExample();
        ex.setOrderByClause("created_at desc");
        ex.createCriteria().andCreatedAtBetween(quarterTimes.get(0), quarterTimes.get(1));
        return modelMapper.selectByExample(ex);
    }

    public List<Date> getQuarterTime() {
        Date now = new Date();
        Date strDate = DateUtil.offset(now, DateField.MONTH, -3);
        Date starTime = DateUtil.parse(DateUtil.formatDate(strDate)+" 00:00:01");
        Date endTime = DateUtil.parse(DateUtil.formatDate(now)+" 23:59:59");
        return CollUtil.newArrayList(starTime, endTime);
    }


    public void addWorkTrend(String title, WorkTrendsTypeEnum typeEnum){
        ParkWorkTrends parkWorkTrends = new ParkWorkTrends();
        parkWorkTrends.setId(SnowflakeIdWorker.getUUID());
        parkWorkTrends.setCreatedAt(new Date());
        parkWorkTrends.setWorkType(typeEnum.value);
        parkWorkTrends.setTitle(title);
        modelMapper.insertSelective(parkWorkTrends);
    }

}
