package com.idea.pro.wx.controller.customerManagement;

import com.github.pagehelper.PageInfo;
import com.idea.customerManagement.dto.RoomSelectionInfoDto;
import com.idea.customerManagement.service.RoomSelectionInfoService;
import com.rockstar.common.base.BaseController;
import com.rockstar.common.domain.AjaxResult;
import com.rockstar.frame.model.extend.DateTrans;
import com.rockstar.frame.model.extend.TableSplitResult;
import com.rockstar.frame.model.extend.Tablepar;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

@Controller
@RequestMapping(value = "/wx/RoomSelectionInfoController")
@Api(tags = "选房管理")
public class WxRoomSelectionInfoController extends BaseController {

    @Autowired
    private RoomSelectionInfoService modelService;

    /**
     * 选房列表回显
     * @param customerManagementId
     * @return
     */
    @PostMapping(value = "listAll",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object list(String customerManagementId){
        List<RoomSelectionInfoDto> result = modelService.listAll(customerManagementId);
        return result;
    }

    /**
     * 选房提交
     * @param houseIds
     * @param customerManagementId
     * @return
     */
    @PostMapping(value = "submit",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult submit(String houseIds, String customerManagementId, String userId){
        int result = modelService.submit(houseIds,customerManagementId,userId);
        return result(result);
    }

    /**
     * 获取定金流水号
     * @param houseId
     * @return
     */
    @PostMapping(value = "getSerialNumber",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public String getSerialNumber(String houseId) {
        return modelService.getSerialNumber(houseId);
    }

    /**
     * 认购金登记
     * @param model
     * @return
     */
    @PostMapping(value = "add",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult add(RoomSelectionInfoDto model,String userId){
        int result = modelService.add(model,userId);
        return result(result);
    }

    /**
     * 认购金修改
     * @param model
     * @return
     */
    @PostMapping(value = "edit",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public AjaxResult edit(RoomSelectionInfoDto model,String userId){
        int result = modelService.edit(model,userId);
        return result(result);
    }

    /**
     * 查看详情
     * @param id
     * @return
     */
    @PostMapping(value = "getById",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object getById(String id){
        return modelService.getById(id);
    }

    /**
     * 房源确认单 下载
     * @param model
     * @param request
     * @param response
     */
    @GetMapping(value = "download",produces = {"application/json;charset=UTF-8"})
    public void download(RoomSelectionInfoDto model, HttpServletRequest request, HttpServletResponse response) {
        modelService.downLoad(model,request,response);
    }

    /**
     * 定金收据下载
     * @param model
     * @param response
     */
    @GetMapping(value = "downLoadReceipt",produces = {"application/json;charset=UTF-8"})
    public void downLoadReceipt(RoomSelectionInfoDto model, HttpServletResponse response) {
        modelService.downLoadReceipt(model,response);
    }

    @PostMapping(value = "list",produces = {"application/json;charset=UTF-8"})
    @ResponseBody
    public Object list(Tablepar tablepar, RoomSelectionInfoDto model, DateTrans dt){
        PageInfo<RoomSelectionInfoDto> page= modelService.listByModel(tablepar,model,dt);
        TableSplitResult<RoomSelectionInfoDto> result = new TableSplitResult<RoomSelectionInfoDto>(page.getPageNum(), page.getTotal(), page.getList());
        return  result;
    }


}
